# frozen_string_literal: true

require 'omniauth-oauth2'

module OmniAuth
  module Strategies
    # Sialog
    class Sialog < OmniAuth::Strategies::OAuth2
      option :name, :sialog

      option :client_options, site: 'https://accounts.sialog.com', authorize_url: '/oauth/authorize'

      uid { raw_info['id'] }

      info do
        {
          name: raw_info['name'],
          last_name: raw_info['last_name'],
          avatar: raw_info['avatar_url'],
          email: raw_info['email'],
          clearance: raw_info['clearance'],
          company_groups: raw_info['company_groups']
        }
      end

      def raw_info
        @raw_info ||= access_token.get('/api/v1/user.json').parsed
      end

      def callback_url
        full_host + script_name + callback_path
      end

      def build_access_token
        options.token_params[:headers] = { Authorization: basic_auth_header }
        super
      end

      def basic_auth_header
        'Basic ' + Base64.strict_encode64("#{options[:client_id]}:#{options[:client_secret]}")
      end
    end
  end
end
